@@ -14,14 +14,15 @@ class CoralClient:
         self.api_key = api_key
         self.atlantis_client_id = atlantis_client_id
 
-    def _get_headers(self, bucket):
+    def _get_headers(self, bucket, region=None):
         return {
             'bucket': bucket,
+            'region': region,
             'atlantisclientid': self.atlantis_client_id,
             'x-api-key': self.api_key
         }
 
-    def get_file(self, bucket, key):
+    def get_file(self, bucket, region, key):
         """Obtém informações de um determinado arquivo.
 
         Exemplo:
@@ -31,10 +32,12 @@ class CoralClient:
             from stl_sdk.torpedo import TorpedoClient
 
             client = CoralSyncClient('https://storage.spacetimeanalytics.com', 'apikey', 'atlantisclientid')
-            file = client.get_file('spacetimelabs-bucket', '/folder/file.ext')
+            file = client.get_file('spacetimelabs-bucket', 'us-west-2', '/folder/file.ext')
 
         :param bucket: Bucket do arquivo
         :type bucket: str
+        :param region: Região do bucket
+        :type region: str
         :param key: Chave do arquivo
         :type key: str
         :return: Objeto do arquivo
@@ -42,7 +45,7 @@ class CoralClient:
         """
         response = requests.get(
                 '{}/api/file'.format(self.coral_url),
-                headers=self._get_headers(bucket),
+                headers=self._get_headers(bucket, region=region),
                 params={
                     'key': key
                 }
