@@ -1,4 +1,6 @@
 import requests
+from stl_sdk.exceptions import CoreHttpError
+from requests.exceptions import HTTPError
 from . import VERSION
 
 
@@ -30,12 +32,15 @@ class WavesClient:
         :return: Objeto do fluxo
         :rtype: dict
         """
-        response = requests.get(
-            '{}/api/workflows/{}'.format(self.waves_url, identifier),
-            headers=self._get_headers(),
-        )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.get(
+                '{}/api/workflows/{}'.format(self.waves_url, identifier),
+                headers=self._get_headers(),
+            )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def create_workflow(self, workflow):
         """Cria um novo fluxo
@@ -57,12 +62,15 @@ class WavesClient:
         :return: Objeto do fluxo criado
         :rtype: dict
         """
-        response = requests.post(
-            '{}/api/workflows'.format(self.waves_url),
-            headers=self._get_headers(),
-            json=workflow)
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.post(
+                '{}/api/workflows'.format(self.waves_url),
+                headers=self._get_headers(),
+                json=workflow)
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def archive_workflow(self, identifier):
         """Arquiva um fluxo
@@ -81,11 +89,14 @@ class WavesClient:
         :return: Objeto do fluxo arquivado
         :rtype: dict
         """
-        response = requests.put(
-            '{}/api/workflows/{}/archive'.format(self.waves_url, identifier),
-            headers=self._get_headers())
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.put(
+                '{}/api/workflows/{}/archive'.format(self.waves_url, identifier),
+                headers=self._get_headers())
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def unarchive_workflow(self, identifier):
         """Desarquiva um fluxo
@@ -104,11 +115,14 @@ class WavesClient:
         :return: Objeto do fluxo desarquivado
         :rtype: dict
         """
-        response = requests.put(
-            '{}/api/workflows/{}/unarchive'.format(self.waves_url, identifier),
-            headers=self._get_headers())
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.put(
+                '{}/api/workflows/{}/unarchive'.format(self.waves_url, identifier),
+                headers=self._get_headers())
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def list_executions(self, term=None, status=None, sort_by=None, page=None, size=None):
         """Busca execuções com os filtros passados
@@ -124,30 +138,33 @@ class WavesClient:
 
         :param term: Palavra-chave de busca (Identificador, descrição ou fluxo)
         :type term: str, opcional
-        :param status: Lista de status desejados (Status possíveis: QUEUED, SUCCESS, CANCELED, FAILURE, STARTED) 
+        :param status: Lista de status desejados (Status possíveis: QUEUED, SUCCESS, CANCELED, FAILURE, STARTED)
         :type status: list, opcional
         :param sort_by: Nome da coluna para ordenação. Utilize "-" para ordem decrescente
         :type sort_by: str, opcional
-        :param page: Número da página atual 
+        :param page: Número da página atual
         :type page: int, opcional
         :param size: Tamanho da página
         :type size: int, opcional
         :return: Objeto da paginação contendo as chaves "meta" e "objects"
         :rtype: dict
         """
-        response = requests.get(
-            '{}/api/executions'.format(self.waves_url),
-            headers=self._get_headers(),
-            params={
-                'term': term, 
-                'status': status,
-                'sort_by': sort_by, 
-                'page': page, 
-                'size': size
-            }
-        )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.get(
+                '{}/api/executions'.format(self.waves_url),
+                headers=self._get_headers(),
+                params={
+                    'term': term,
+                    'status': status,
+                    'sort_by': sort_by,
+                    'page': page,
+                    'size': size
+                }
+            )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def get_execution(self, identifier):
         """Obtem uma execução por ID
@@ -166,12 +183,15 @@ class WavesClient:
         :return: Objeto da execução
         :rtype: dict
         """
-        response = requests.get(
-            '{}/api/executions/{}'.format(self.waves_url, identifier),
-            headers=self._get_headers(),
-        )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.get(
+                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                headers=self._get_headers(),
+            )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def create_execution(self, workflow_identifier, inputs, description=None):
         """Cria uma execução a partir de um fluxo e uma lista de entradas
@@ -194,16 +214,19 @@ class WavesClient:
         :return: Objeto da execução criada
         :rtype: dict
         """
-        response = requests.post(
-            '{}/api/executions'.format(self.waves_url),
-            headers=self._get_headers(),
-            json={
-                "workflow_identifier": workflow_identifier,
-                "inputs": inputs,
-                "description": description
-            })
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.post(
+                '{}/api/executions'.format(self.waves_url),
+                headers=self._get_headers(),
+                json={
+                    "workflow_identifier": workflow_identifier,
+                    "inputs": inputs,
+                    "description": description
+                })
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def update_execution(self, identifier, description=None):
         """Atualiza os dados de uma execução. Atualmente só é possível atualizar a sua descrição
@@ -224,14 +247,17 @@ class WavesClient:
         :return: Objeto da execução atualizada
         :rtype: dict
         """
-        response = requests.put(
-            '{}/api/executions/{}'.format(self.waves_url, identifier),
-            headers=self._get_headers(),
-            json={
-                "description": description
-            })
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.put(
+                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                headers=self._get_headers(),
+                json={
+                    "description": description
+                })
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def delete_execution(self, identifier):
         """Realiza um SOFT DELETE na execução desejada
@@ -248,10 +274,13 @@ class WavesClient:
         :param identifier: Id da execução
         :type identifier: str
         """
-        response = requests.delete(
-            '{}/api/executions/{}'.format(self.waves_url, identifier),
-            headers=self._get_headers())
-        response.raise_for_status()
+        try:
+            response = requests.delete(
+                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                headers=self._get_headers())
+            response.raise_for_status()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def create_businesstask(self, btask):
         """Cria uma nova tarefa
@@ -273,12 +302,15 @@ class WavesClient:
         :return: Objeto da tarefa criada
         :rtype: dict
         """
-        response = requests.post(
-            '{}/api/business-tasks'.format(self.waves_url),
-            headers=self._get_headers(),
-            json=btask)
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.post(
+                '{}/api/business-tasks'.format(self.waves_url),
+                headers=self._get_headers(),
+                json=btask)
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def publish_businesstask(self, identifier):
         """Pública uma tarefa não publicada
@@ -297,11 +329,14 @@ class WavesClient:
         :return: Objeto da tarefa publicada
         :rtype: dict
         """
-        response = requests.put(
-            '{}/api/business-tasks/{}/publish'.format(self.waves_url, identifier),
-            headers=self._get_headers())
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.put(
+                '{}/api/business-tasks/{}/publish'.format(self.waves_url, identifier),
+                headers=self._get_headers())
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def unpublish_businesstask(self, identifier):
         """Despública uma tarefa publicada
@@ -320,11 +355,14 @@ class WavesClient:
         :return: Objeto da tarefa despublicada
         :rtype: dict
         """
-        response = requests.put(
-            '{}/api/business-tasks/{}/unpublish'.format(self.waves_url, identifier),
-            headers=self._get_headers())
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.put(
+                '{}/api/business-tasks/{}/unpublish'.format(self.waves_url, identifier),
+                headers=self._get_headers())
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def list_workers(self):
         """Lista os workers da aplicação
@@ -341,12 +379,15 @@ class WavesClient:
         :return: Objeto dos workers da aplicação
         :rtype: dict
         """
-        response = requests.get(
-            '{}/api/workers'.format(self.waves_url),
-            headers=self._get_headers(),
-        )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.get(
+                '{}/api/workers'.format(self.waves_url),
+                headers=self._get_headers(),
+            )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise WavesClientHTTPError(error)
 
     def _get_headers(self):
         headers = {
@@ -354,3 +395,7 @@ class WavesClient:
             'X-API-KEY': self.api_key
         }
         return headers
+
+
+class WavesClientHTTPError(CoreHttpError):
+    pass
